*********************
pip requirement files
*********************

The files found here are `requirement files
<http://www.pip-installer.org/en/latest/requirements.html>`_ that may be used
with `pip <http://www.pip-installer.org/>`_.

To install the dependencies found in one of these files, simply run e.g.::

    pip install -r requirements/tests.txt
